.. _settings:

.. module:: pulsar.utils.config

=======================
Settings
=======================

This is the full list of :class:`pulsar.Setting` available for configuring
your pulsar server or application.


.. pulsar_settings::
